@@ -1,5 +1,5 @@
 from bdaserviceutils import task_args
-
+from .utils import get_dataset_property
 import importlib
 
 
@@ -7,8 +7,8 @@ def get_args():
 
     args = task_args.get_args()
 
-    if args["dataStorageType-input-dataset"].lower().startswith("presto"):
-        args["input-columns"] = args["input-columns"] if "input-columns" in args else "*"
+    # if args["dataStorageType-input-dataset"].lower().startswith("presto"):
+    #     args["input-columns"] = args["input-columns"] if "input-columns" in args else "*"
 
     return args
 
@@ -19,32 +19,32 @@ def get_class(module_name):
     return getattr(module, module_name.capitalize())
 
 
-def load_dataset(sc, read_all, input_dest='', header=True):
+def load_dataset(sc, name, read_all, input_dest='', header=True):
     # sc -> Spark context
     # read_all -> True to read all data, False to read 'input-columns' in 'args'
 
     args = get_args()
-    data_storage = args["dataStorageType-input-dataset"]
+    data_storage = get_dataset_property(name=name, prop='dataStorageType') #args["dataStorageType-input-dataset"]
     module_name = data_storage.split('-')[0].lower()
 
     class_ = get_class(module_name)
     instance = class_(args, sc)
 
-    return instance.load_dataset(read_all, input_dest, header)
+    return instance.load_dataset(name, read_all, input_dest, header)
 
 
-def save_dataset(sc, df, output_dest=''):
+def save_dataset(sc, name, df, output_dest=''):
     # df -> Spark dataframe to store
     # output_dest -> destinaion output, if not specified it takes 'output-dataset' destinaion from 'args'
 
     args = get_args()
-    data_storage = args["dataStorageType-output-dataset"]
+    data_storage = get_dataset_property(name=name, prop='dataStorageType') #args["dataStorageType-input-dataset"]
     module_name = data_storage.split('-')[0].lower()
 
     class_ = get_class(module_name)
     instance = class_(args, sc)
 
-    return instance.save_dataset(df, output_dest)
+    return instance.save_dataset(name, df, output_dest)
 
 
 def lower_columns_list(columns_list):
