@@ -1,5 +1,5 @@
 from .datastorage import DataStorage
-
+from .utils import get_dataset_property
 
 class Mongo(DataStorage):
 
@@ -13,7 +13,7 @@ class Mongo(DataStorage):
 
 
     # overriding abstract method
-    def load_dataset(self, read_all=True, input_dest=None, header=True):
+    def load_dataset(self, name, read_all=True, input_dest=None, header=True):
 
         if input_dest is None:
             input_dest = self.args["input-dataset"]
@@ -28,7 +28,7 @@ class Mongo(DataStorage):
 
 
     # overriding abstract method
-    def save_dataset(self, df, output_dest=None):
+    def save_dataset(self, name, df, output_dest=None):
 
         if output_dest is None:
             output_dest = self.args["output-dataset"]
