@@ -21,25 +21,24 @@ def auto_conf_generator(args):
     args_name = {
         # Hive
         "spark.sql.warehouse.dir" : "spark.sql.warehouse.dir",
-        "hiveMetastoreUris-input-dataset" : "hive.metastore.uris",
-        "hiveMetastoreUris-output-dataset" : "hive.metastore.uris",
+        "hiveMetastoreUris" : "hive.metastore.uris",
+        "hiveMetastoreUris" : "hive.metastore.uris",
         # MinIO
         "minIO_URL" : "spark.hadoop.fs.s3a.endpoint",
         "minIO_ACCESS_KEY" : "spark.hadoop.fs.s3a.access.key",
         "minIO_SECRET_KEY" : "spark.hadoop.fs.s3a.secret.key" ,
-        "minIO_URL-input-dataset" : "spark.hadoop.fs.s3a.endpoint",
-        "minIO_ACCESS_KEY-input-dataset" : "spark.hadoop.fs.s3a.access.key",
-        "minIO_SECRET_KEY-input-dataset" : "spark.hadoop.fs.s3a.secret.key",
-        "minIO_URL-output-dataset" : "spark.hadoop.fs.s3a.endpoint",
-        "minIO_ACCESS_KEY-output-dataset" : "spark.hadoop.fs.s3a.access.key",
-        "minIO_SECRET_KEY-output-dataset" : "spark.hadoop.fs.s3a.secret.key"
     }
 
     result = []
 
+    # for key in args_name:
+    #     if key in args:
+    #         result.append((args_name[key], args[key]))
+    
     for key in args_name:
-        if key in args:
-            result.append((args_name[key], args[key]))
+        for arg in args:
+            if key in arg:
+                result.append((args_name[key], args[arg]))
     
     return result
 
